/* ZGV v2.0 - (c) 1993,1994 Russell Marks for improbabledesigns.
 * See README for license details.
 *
 * vgadisp.h - prototypes for vgadisp.c
 */


/* required for config reading/writing by zgv.c */
/* pixelsize is also reqd. by usejpeg.c */
extern int curvgamode,zoom,virtual,vkludge,brightness,pixelsize;
extern double contrast;

/* reqd. by zgv.c:makexv332() */
extern unsigned char *theimage,*image_palette;
extern int width,height;

extern int readpicture(char *,hffunc,int);
extern int is_this_file_jpeg();
